@@ -73,8 +73,8 @@ def _add_invoice_custom_headers(writer, invoices):
     for tva in Tva.query():
         writer.add_extra_header(
             {
-                "label": u"HT {tva.name}".format(tva=tva),
-                "name": u"HT {tva.value}".format(tva=tva),
+                "label": "HT {tva.name}".format(tva=tva),
+                "name": "HT {tva.value}".format(tva=tva),
             }
         )
         writer.add_extra_header({"label": tva.name, "name": tva.value})
@@ -184,7 +184,7 @@ def includeme(config):
     config.register_import_model(
         key="userdatas",
         model=UserDatas,
-        label=u"Données de gestion sociale",
+        label="Données de gestion sociale",
         permission="admin_userdatas",
         excludes=(
             "name",
@@ -200,7 +200,7 @@ def includeme(config):
     config.register_import_model(
         key="customers",
         model=Customer,
-        label=u"Clients",
+        label="Clients",
         permission="add_customer",
         excludes=(
             "created_at",
@@ -217,7 +217,7 @@ def includeme(config):
     config.register_import_model(
         key="suppliers",
         model=Supplier,
-        label=u"Fournisseurs",
+        label="Fournisseurs",
         permission="add_supplier",
         excludes=(
             "created_at",
